==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QImage_shell.h <==
#ifndef QIMAGE_SHELL_H
#define QIMAGE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qimage.h>
#include <QtJambi/QtJambiAPI>
#include <QStringList>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcolorspace.h>
#include <QtGui/qcolortransform.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixelformat.h>
#include <QtGui/qtransform.h>
#include <QtJambi/JavaAPI>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QImage_shell : public QImage, public QtJambiShellInterface
{
public:
    QImage_shell();
    QImage_shell(const QImage& arg__1);
    QImage_shell(const QSize& size0, QImage::Format format1);
    QImage_shell(const QString& fileName0, const char* format1 = nullptr);
    QImage_shell(const char*const * xpm0);
    QImage_shell(const uchar* data0, int width1, int height2, QImage::Format format3, QImageCleanupFunction cleanupFunction4 = nullptr, void* cleanupInfo5 = nullptr);
    QImage_shell(int width0, int height1, QImage::Format format2);
    ~QImage_shell() override;

    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric metric0) const override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    QPainter* sharedPainter() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QImage_access : public QImage
{
    void __qt_detachMetadata_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean invalidateCache0);
    jobject __qt_smoothScaled_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint w0, jint h1) const;
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0) const;
    jobject __qt_paintEngine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jobject __qt_sharedPainter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QIMAGE_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QImage_shell.h <==
#ifndef QIMAGE_SHELL_H
#define QIMAGE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qimage.h>
#include <QtJambi/QtJambiAPI>
#include <QStringList>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qbytearrayview.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcolorspace.h>
#include <QtGui/qcolortransform.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixelformat.h>
#include <QtGui/qtransform.h>
#include <QtJambi/JavaAPI>
#include <QtJambiGui/hashes.h>
#include <QtJambi/RegistryAPI>


class QImage_shell : public QImage, public QtJambiShellInterface
{
public:
    QImage_shell();
    QImage_shell(const QImage& arg__1);
    QImage_shell(const QSize& size0, QImage::Format format1);
    QImage_shell(const QString& fileName0, const char* format1 = nullptr);
    QImage_shell(const char*const * xpm0);
    QImage_shell(const uchar* data0, int width1, int height2, QImage::Format format3, QImageCleanupFunction cleanupFunction4 = nullptr, void* cleanupInfo5 = nullptr);
    QImage_shell(int width0, int height1, QImage::Format format2);
    ~QImage_shell() override;

    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric metric0) const override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    QPainter* sharedPainter() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QImage_access : public QImage
{
    void __qt_detachMetadata_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean invalidateCache0);
    jobject __qt_smoothScaled_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint w0, jint h1) const;
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint metric0) const;
    jobject __qt_paintEngine_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    jobject __qt_sharedPainter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QIMAGE_SHELL_H
